@@ -1,22 +1,21 @@
 # vim: ts=4:sw=4:expandtab
 
-## BleachBit
-## Copyright (C) 2013 Andrew Ziem
-## http://bleachbit.sourceforge.net
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+# BleachBit
+# Copyright (C) 2014 Andrew Ziem
+# http://bleachbit.sourceforge.net
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 """
@@ -24,7 +23,6 @@ Perform (or assist with) cleaning operations.
 """
 
 
-
 import glob
 try:
     import gtk
@@ -56,6 +54,7 @@ backends = {}
 
 
 class Cleaner:
+
     """Base class for a cleaner"""
 
     def __init__(self):
@@ -71,15 +70,15 @@ class Cleaner:
         """Register 'action' (instance of class Action) to be executed
         for ''option_id'.  The actions must implement list_files and
         other_cleanup()"""
-        self.actions += ( (option_id, action), )
+        self.actions += ((option_id, action), )
 
     def add_option(self, option_id, name, description):
         """Register option (such as 'cache')"""
-        self.options[option_id] = ( name, description )
+        self.options[option_id] = (name, description)
 
     def add_running(self, detection_type, pathname):
         """Add a way to detect this program is currently running"""
-        self.running += ( (detection_type, pathname), )
+        self.running += ((detection_type, pathname), )
 
     def auto_hide(self):
         """Return boolean whether it is OK to automatically hide this
@@ -139,7 +138,6 @@ class Cleaner:
             for key in sorted(self.options.keys()):
                 yield (key, self.options[key][0])
 
-
     def get_warning(self, option_id):
         """Return a warning as string."""
         if option_id in self.warnings:
@@ -167,7 +165,8 @@ class Cleaner:
                         print "debug: file '%s' exists indicating '%s' is running" % (globbed, self.name)
                         return True
             else:
-                raise RuntimeError("Unknown running-detection test '%s'" % test)
+                raise RuntimeError(
+                    "Unknown running-detection test '%s'" % test)
         return False
 
     def is_usable(self):
@@ -180,30 +179,41 @@ class Cleaner:
 
 
 class Firefox(Cleaner):
+
     """Mozilla Firefox"""
 
     def __init__(self):
         Cleaner.__init__(self)
-        self.add_option('cache', _('Cache'), _('Delete the web cache, which reduces time to display revisited pages'))
-        self.add_option('cookies', _('Cookies'), _('Delete cookies, which contain information such as web site preferences, authentication, and tracking identification'))
-        self.add_option('crash_reports', _('Crash reports'), _('Delete the files'))
+        self.add_option('cache', _('Cache'), _(
+            'Delete the web cache, which reduces time to display revisited pages'))
+        self.add_option('cookies', _('Cookies'), _(
+            'Delete cookies, which contain information such as web site preferences, authentication, and tracking identification'))
+        self.add_option(
+            'crash_reports', _('Crash reports'), _('Delete the files'))
         # TRANSLATORS: DOM = Document Object Model.
         self.add_option('dom', _('DOM Storage'), _('Delete HTML5 cookies'))
-        self.add_option('download_history', _('Download history'), _('List of files downloaded'))
-        self.add_option('forms', _('Form history'), _('A history of forms entered in web sites and in the Search bar'))
-        self.add_option('session_restore', _('Session restore'), _('Loads the initial session after the browser closes or crashes'))
-        self.add_option('site_preferences', _('Site preferences'), _('Settings for individual sites'))
-        self.add_option('passwords', _('Passwords'), _('A database of usernames and passwords as well as a list of sites that should not store passwords'))
-        self.add_option('url_history', _('URL history'), _('List of visited web pages'))
-        self.add_option('vacuum', _('Vacuum'), _('Clean database fragmentation to reduce space and improve speed without removing any data'))
+        self.add_option('download_history', _(
+            'Download history'), _('List of files downloaded'))
+        self.add_option('forms', _('Form history'), _(
+            'A history of forms entered in web sites and in the Search bar'))
+        self.add_option('session_restore', _('Session restore'), _(
+            'Loads the initial session after the browser closes or crashes'))
+        self.add_option('site_preferences', _(
+            'Site preferences'), _('Settings for individual sites'))
+        self.add_option('passwords', _('Passwords'), _(
+            'A database of usernames and passwords as well as a list of sites that should not store passwords'))
+        self.add_option(
+            'url_history', _('URL history'), _('List of visited web pages'))
+        self.add_option('vacuum', _('Vacuum'), _(
+            'Clean database fragmentation to reduce space and improve speed without removing any data'))
 
         if 'posix' == os.name:
-            self.profile_dir = "~/.mozilla/firefox*/*/"
+            self.profile_dir = "~/.mozilla/firefox*/*.default*/"
             self.add_running('exe', 'firefox')
             self.add_running('exe', 'firefox-bin')
             self.add_running('pathname', self.profile_dir + 'lock')
         elif 'nt' == os.name:
-            self.profile_dir = "$USERPROFILE\\Application Data\\Mozilla\\Firefox\\Profiles\\*\\"
+            self.profile_dir = "$USERPROFILE\\Application Data\\Mozilla\\Firefox\\Profiles\\*.default*\\"
             self.add_running('exe', 'firefox.exe')
 
     def get_description(self):
@@ -221,63 +231,81 @@ class Firefox(Cleaner):
         if 'posix' == os.name:
             cache_base = self.profile_dir
         elif 'nt' == os.name:
-            cache_base = "$localappdata\\Mozilla\\Firefox\\Profiles\\*"
+            cache_base = "$localappdata\\Mozilla\\Firefox\\Profiles\\*.default*"
         if 'cache' == option_id:
             dirs = FileUtilities.expand_glob_join(cache_base, "Cache*")
             dirs += FileUtilities.expand_glob_join(cache_base, "OfflineCache")
             if 'nt' == os.name:
-                dirs += FileUtilities.expand_glob_join(cache_base, "jumpListCache") # Windows 8
+                dirs += FileUtilities.expand_glob_join(
+                    cache_base, "jumpListCache")  # Windows 8
             for dirname in dirs:
                 for filename in children_in_directory(dirname, False):
                     yield Command.Delete(filename)
         files = []
         # cookies
         if 'cookies' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "cookies.txt")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "cookies.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "cookies.txt")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "cookies.sqlite")
         # crash reports
         if 'posix' == os.name:
             crashdir = os.path.expanduser("~/.mozilla/firefox/Crash Reports")
         if 'nt' == os.name:
-            crashdir = os.path.expandvars("$USERPROFILE\\Application Data\\Mozilla\\Firefox\\Crash Reports")
+            crashdir = os.path.expandvars(
+                "$USERPROFILE\\Application Data\\Mozilla\\Firefox\\Crash Reports")
         if 'crash_reports' == option_id:
             for filename in children_in_directory(crashdir, False):
-                files += [ filename ]
-            files += FileUtilities.expand_glob_join(self.profile_dir, "minidumps/*.dmp")
+                files += [filename]
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "minidumps/*.dmp")
         # DOM storage
         if 'dom' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "webappsstore.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "webappsstore.sqlite")
 
         # download history
         if 'download_history' == option_id:
             # Firefox version 1
-            files += FileUtilities.expand_glob_join(self.profile_dir, "downloads.rdf")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "downloads.rdf")
             # Firefox version 3
-            files += FileUtilities.expand_glob_join(self.profile_dir, "downloads.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "downloads.sqlite")
         # forms
         if 'forms' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "formhistory.dat")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "formhistory.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "formhistory.dat")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "formhistory.sqlite")
         # passwords
         if 'passwords' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "signons.txt")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "signons[2-3].txt")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "signons.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "signons.txt")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "signons[2-3].txt")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "signons.sqlite")
         # session restore
         if 'session_restore' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "sessionstore.js")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "sessionstore.bak")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "sessionstore.js")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "sessionstore.bak")
         # site-specific preferences
         if 'site_preferences' == option_id:
-            files += FileUtilities.expand_glob_join(self.profile_dir, "content-prefs.sqlite")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "content-prefs.sqlite")
 
         # URL history
         if 'url_history' == option_id:
             # Firefox version 1
-            files += FileUtilities.expand_glob_join(self.profile_dir, "history.dat")
+            files += FileUtilities.expand_glob_join(
+                self.profile_dir, "history.dat")
             # Firefox 21 on Windows
             if 'nt' == os.name:
-                files += FileUtilities.expand_glob_join(cache_base, "thumbnails/*.png")
+                files += FileUtilities.expand_glob_join(
+                    cache_base, "thumbnails/*.png")
             # see also function other_cleanup()
         # finish
         for filename in files:
@@ -286,37 +314,41 @@ class Firefox(Cleaner):
         # URL history
         if 'url_history' == option_id:
             for path in FileUtilities.expand_glob_join(self.profile_dir, "places.sqlite"):
-                yield Command.Function(path, \
-                        Special.delete_mozilla_url_history,
-                        _('Delete the usage history'))
+                yield Command.Function(path,
+                                       Special.delete_mozilla_url_history,
+                                       _('Delete the usage history'))
 
         # vacuum
         if 'vacuum' == option_id:
             paths = []
-            paths += FileUtilities.expand_glob_join(self.profile_dir, "*.sqlite")
+            paths += FileUtilities.expand_glob_join(
+                self.profile_dir, "*.sqlite")
             if not cache_base == self.profile_dir:
                 paths += FileUtilities.expand_glob_join(cache_base, "*.sqlite")
             for path in paths:
-                yield Command.Function(path, \
-                    FileUtilities.vacuum_sqlite3, _("Vacuum"))
-
+                yield Command.Function(path,
+                                       FileUtilities.vacuum_sqlite3, _("Vacuum"))
 
 
 class OpenOfficeOrg(Cleaner):
+
     """Delete OpenOffice.org cache"""
 
     def __init__(self):
         Cleaner.__init__(self)
         self.options = {}
         self.add_option('cache', _('Cache'), _('Delete the cache'))
-        self.add_option('recent_documents', _('Most recently used'), _("Delete the list of recently used documents"))
+        self.add_option('recent_documents', _('Most recently used'), _(
+            "Delete the list of recently used documents"))
 
         # reference: http://katana.oooninja.com/w/editions_of_openoffice.org
         if 'posix' == os.name:
-            self.prefixes = [ "~/.ooo-2.0", "~/.openoffice.org2", "~/.openoffice.org2.0", "~/.openoffice.org/3" ]
-            self.prefixes += [ "~/.ooo-dev3" ]
+            self.prefixes = ["~/.ooo-2.0", "~/.openoffice.org2",
+                             "~/.openoffice.org2.0", "~/.openoffice.org/3"]
+            self.prefixes += ["~/.ooo-dev3"]
         if 'nt' == os.name:
-            self.prefixes = [ "$APPDATA\\OpenOffice.org\\3", "$APPDATA\\OpenOffice.org2" ]
+            self.prefixes = [
+                "$APPDATA\\OpenOffice.org\\3", "$APPDATA\\OpenOffice.org2"]
 
     def get_description(self):
         return _("Office suite")
@@ -337,7 +369,6 @@ class OpenOfficeOrg(Cleaner):
                     if os.path.lexists(path):
                         yield Command.Delete(path)
 
-
         if 'recent_documents' == option_id and not 'cache' == option_id:
             for prefix in self.prefixes:
                 for path in FileUtilities.expand_glob_join(prefix, "user/registry/cache/org.openoffice.Office.Common.dat"):
@@ -347,100 +378,116 @@ class OpenOfficeOrg(Cleaner):
         if 'cache' == option_id:
             dirs = []
             for prefix in self.prefixes:
-                dirs += FileUtilities.expand_glob_join(prefix, "user/registry/cache/")
+                dirs += FileUtilities.expand_glob_join(
+                    prefix, "user/registry/cache/")
             for dirname in dirs:
                 for filename in children_in_directory(dirname, False):
                     yield Command.Delete(filename)
 
-
         if 'recent_documents' == option_id:
             for prefix in self.prefixes:
                 for path in FileUtilities.expand_glob_join(prefix, "user/registry/data/org/openoffice/Office/Common.xcu"):
                     if os.path.lexists(path):
-                        yield Command.Function(path, \
-                            Special.delete_ooo_history,
-                            _('Delete the usage history'))
+                        yield Command.Function(path,
+                                               Special.delete_ooo_history,
+                                               _('Delete the usage history'))
                 # ~/.openoffice.org/3/user/registrymodifications.xcu
                 #       Apache OpenOffice.org 3.4.1 from openoffice.org on Ubuntu 13.04
                 # %AppData%\OpenOffice.org\3\user\registrymodifications.xcu
-                #       Apache OpenOffice.org 3.4.1 from openoffice.org on Windows XP
+                # Apache OpenOffice.org 3.4.1 from openoffice.org on Windows XP
                 for path in FileUtilities.expand_glob_join(prefix, "user/registrymodifications.xcu"):
                     if os.path.lexists(path):
-                        yield Command.Function(path, \
-                            Special.delete_office_registrymodifications,
-                            _('Delete the usage history'))
+                        yield Command.Function(path,
+                                               Special.delete_office_registrymodifications,
+                                               _('Delete the usage history'))
+
 
 class System(Cleaner):
+
     """Clean the system in general"""
 
     def __init__(self):
         Cleaner.__init__(self)
 
-        ###
-        ### options for Linux and BSD
-        ###
+        #
+        # options for Linux and BSD
+        #
         if 'posix' == os.name:
             # TRANSLATORS: desktop entries are .desktop files in Linux tha
             # make up the application menu (the menu that shows BleachBit,
             # Firefox, and others.  The .desktop files also associate file
             # types, so clicking on an .html file in Nautilus brings up
             # Firefox.
-            # More information: http://standards.freedesktop.org/menu-spec/latest/index.html#introduction
-            self.add_option('desktop_entry', _('Broken desktop files'), _('Delete broken application menu entries and file associations'))
+            # More information:
+            # http://standards.freedesktop.org/menu-spec/latest/index.html#introduction
+            self.add_option('desktop_entry', _('Broken desktop files'), _(
+                'Delete broken application menu entries and file associations'))
             self.add_option('cache', _('Cache'), _('Delete the cache'))
             # TRANSLATORS: Localizations are files supporting specific
             # languages, so applications appear in Spanish, etc.
-            self.add_option('localizations', _('Localizations'), _('Delete files for unwanted languages'))
-            self.set_warning('localizations', _("Configure this option in the preferences."))
+            self.add_option('localizations', _('Localizations'), _(
+                'Delete files for unwanted languages'))
+            self.set_warning(
+                'localizations', _("Configure this option in the preferences."))
             # TRANSLATORS: 'Rotated logs' refers to old system log files.
             # Linux systems often have a scheduled job to rotate the logs
             # which means compress all except the newest log and then delete
             # the oldest log.  You could translate this 'old logs.'
-            self.add_option('rotated_logs', _('Rotated logs'), _('Delete old system logs'))
-            self.add_option('recent_documents', _('Recent documents list'), _('Delete the list of recently used documents'))
+            self.add_option(
+                'rotated_logs', _('Rotated logs'), _('Delete old system logs'))
+            self.add_option('recent_documents', _('Recent documents list'), _(
+                'Delete the list of recently used documents'))
             self.add_option('trash', _('Trash'), _('Empty the trash'))
 
-        ###
-        ### options just for Linux
-        ###
+        #
+        # options just for Linux
+        #
         if sys.platform.startswith('linux'):
-            self.add_option('memory', _('Memory'), \
-            # TRANSLATORS: 'free' means 'unallocated'
-               _('Wipe the swap and free memory'))
-            self.set_warning('memory', _('This option is experimental and may cause system problems.'))
+            self.add_option('memory', _('Memory'),
+                            # TRANSLATORS: 'free' means 'unallocated'
+                            _('Wipe the swap and free memory'))
+            self.set_warning(
+                'memory', _('This option is experimental and may cause system problems.'))
 
-        ###
-        ### options just for Microsoft Windows
-        ###
+        #
+        # options just for Microsoft Windows
+        #
         if 'nt' == os.name:
             self.add_option('logs', _('Logs'), _('Delete the logs'))
-            self.add_option('memory_dump', _('Memory dump'), _('Delete the file memory.dmp'))
+            self.add_option(
+                'memory_dump', _('Memory dump'), _('Delete the file memory.dmp'))
             self.add_option('muicache', 'MUICache', _('Delete the cache'))
             # TRANSLATORS: Prefetch is Microsoft Windows jargon.
             self.add_option('prefetch', _('Prefetch'), _('Delete the cache'))
-            self.add_option('recycle_bin', _('Recycle bin'), _('Empty the recycle bin'))
+            self.add_option(
+                'recycle_bin', _('Recycle bin'), _('Empty the recycle bin'))
             # TRANSLATORS: 'Update' is a noun, and 'Update uninstallers' is an option to delete
             # the uninstallers for software updates.
-            self.add_option('updates', _('Update uninstallers'), _('Delete uninstallers for Microsoft updates including hotfixes, service packs, and Internet Explorer updates'))
+            self.add_option('updates', _('Update uninstallers'), _(
+                'Delete uninstallers for Microsoft updates including hotfixes, service packs, and Internet Explorer updates'))
 
-        ###
-        ### options for GTK+
-        ###
+        #
+        # options for GTK+
+        #
 
         if HAVE_GTK:
-            self.add_option('clipboard', _('Clipboard'), _('The desktop environment\'s clipboard used for copy and paste operations'))
+            self.add_option('clipboard', _('Clipboard'), _(
+                'The desktop environment\'s clipboard used for copy and paste operations'))
 
-        ###
-        ### options common to all platforms
-        ###
-        # TRANSLATORS: "Custom" is an option allowing the user to specify which files and folders will be erased.
-        self.add_option('custom', _('Custom'), _('Delete user-specified files and folders'))
+        #
+        # options common to all platforms
+        #
+        # TRANSLATORS: "Custom" is an option allowing the user to specify which
+        # files and folders will be erased.
+        self.add_option('custom', _('Custom'), _(
+            'Delete user-specified files and folders'))
         # TRANSLATORS: 'free' means 'unallocated'
-        self.add_option('free_disk_space', _('Free disk space'), \
-            # TRANSLATORS: 'free' means 'unallocated'
-            _('Overwrite free disk space to hide deleted files'))
+        self.add_option('free_disk_space', _('Free disk space'),
+                        # TRANSLATORS: 'free' means 'unallocated'
+                        _('Overwrite free disk space to hide deleted files'))
         self.set_warning('free_disk_space', _('This option is very slow.'))
-        self.add_option('tmp', _('Temporary files'), _('Delete the temporary files'))
+        self.add_option(
+            'tmp', _('Temporary files'), _('Delete the temporary files'))
 
     def get_description(self):
         return _("The system in general")
@@ -463,36 +510,37 @@ class System(Cleaner):
             for filename in children_in_directory(dirname, True):
                 if self.whitelisted(filename):
                     continue
-                files += [ filename ]
+                files += [filename]
 
         # custom
         if 'custom' == option_id:
             for (c_type, c_path) in options.get_custom_paths():
                 if 'file' == c_type:
-                    files += [ c_path ]
+                    files += [c_path]
                 elif 'folder' == c_type:
-                    files += [ c_path ]
+                    files += [c_path]
                     for path in children_in_directory(c_path, True):
-                        files += [ path ]
+                        files += [path]
                 else:
-                    raise RuntimeError('custom folder has invalid type %s' % c_type)
+                    raise RuntimeError(
+                        'custom folder has invalid type %s' % c_type)
 
         # menu
-        menu_dirs = [ '~/.local/share/applications', \
-            '~/.config/autostart', \
-            '~/.gnome/apps/', \
-            '~/.gnome2/panel2.d/default/launchers', \
-            '~/.gnome2/vfolders/applications/', \
-            '~/.kde/share/apps/RecentDocuments/', \
-            '~/.kde/share/mimelnk', \
-            '~/.kde/share/mimelnk/application/ram.desktop', \
-            '~/.kde2/share/mimelnk/application/', \
-            '~/.kde2/share/applnk' ]
+        menu_dirs = ['~/.local/share/applications',
+                     '~/.config/autostart',
+                     '~/.gnome/apps/',
+                     '~/.gnome2/panel2.d/default/launchers',
+                     '~/.gnome2/vfolders/applications/',
+                     '~/.kde/share/apps/RecentDocuments/',
+                     '~/.kde/share/mimelnk',
+                     '~/.kde/share/mimelnk/application/ram.desktop',
+                     '~/.kde2/share/mimelnk/application/',
+                     '~/.kde2/share/applnk']
 
         if 'posix' == os.name and 'desktop_entry' == option_id:
             for dirname in menu_dirs:
-                for filename in [fn for fn in children_in_directory(dirname, False) \
-                    if fn.endswith('.desktop') ]:
+                for filename in [fn for fn in children_in_directory(dirname, False)
+                                 if fn.endswith('.desktop')]:
                     if Unix.is_broken_xdg_desktop(filename):
                         yield Command.Delete(filename)
 
@@ -504,46 +552,46 @@ class System(Cleaner):
 
         # Windows logs
         if 'nt' == os.name and 'logs' == option_id:
-            paths = ( \
-                '$ALLUSERSPROFILE\\Application Data\\Microsoft\\Dr Watson\\*.log', \
-                '$ALLUSERSPROFILE\\Application Data\\Microsoft\\Dr Watson\\user.dmp', \
-                '$LocalAppData\\Microsoft\\Windows\\WER\\ReportArchive\\*\\*', \
-                '$LocalAppData\\Microsoft\\Windows\WER\\ReportQueue\\*\\*', \
-                '$programdata\\Microsoft\\Windows\\WER\\ReportArchive\\*\\*', \
-                '$programdata\\Microsoft\\Windows\\WER\\ReportQueue\\*\\*', \
-                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.bak', \
-                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.txt', \
-                '$windir\\*.log', \
-                '$windir\\imsins.BAK', \
-                '$windir\\OEWABLog.txt', \
-                '$windir\\SchedLgU.txt', \
-                '$windir\\ntbtlog.txt', \
-                '$windir\\setuplog.txt', \
-                '$windir\\REGLOCS.OLD', \
-                '$windir\\Debug\\*.log', \
-                '$windir\\Debug\\Setup\\UpdSh.log', \
-                '$windir\\Debug\\UserMode\\*.log', \
-                '$windir\\Debug\\UserMode\\ChkAcc.bak', \
-                '$windir\\Debug\\UserMode\\userenv.bak', \
-                '$windir\\Microsoft.NET\Framework\*\*.log', \
-                '$windir\\pchealth\\helpctr\\Logs\\hcupdate.log', \
-                '$windir\\security\\logs\\*.log', \
-                '$windir\\security\\logs\\*.old', \
-                '$windir\\system32\\TZLog.log', \
-                '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.bak', \
-                '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.txt', \
-                '$windir\\system32\\LogFiles\\AIT\\AitEventLog.etl.???', \
-                '$windir\\system32\\LogFiles\\Firewall\\pfirewall.log*', \
-                '$windir\\system32\\LogFiles\\Scm\\SCM.EVM*', \
-                '$windir\\system32\\LogFiles\\WMI\\Terminal*.etl', \
-                '$windir\\system32\\LogFiles\\WMI\\RTBackup\EtwRT.*etl', \
-                '$windir\\system32\\wbem\\Logs\\*.lo_', \
+            paths = (
+                '$ALLUSERSPROFILE\\Application Data\\Microsoft\\Dr Watson\\*.log',
+                '$ALLUSERSPROFILE\\Application Data\\Microsoft\\Dr Watson\\user.dmp',
+                '$LocalAppData\\Microsoft\\Windows\\WER\\ReportArchive\\*\\*',
+                '$LocalAppData\\Microsoft\\Windows\WER\\ReportQueue\\*\\*',
+                '$programdata\\Microsoft\\Windows\\WER\\ReportArchive\\*\\*',
+                '$programdata\\Microsoft\\Windows\\WER\\ReportQueue\\*\\*',
+                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.bak',
+                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.txt',
+                '$windir\\*.log',
+                '$windir\\imsins.BAK',
+                '$windir\\OEWABLog.txt',
+                '$windir\\SchedLgU.txt',
+                '$windir\\ntbtlog.txt',
+                '$windir\\setuplog.txt',
+                '$windir\\REGLOCS.OLD',
+                '$windir\\Debug\\*.log',
+                '$windir\\Debug\\Setup\\UpdSh.log',
+                '$windir\\Debug\\UserMode\\*.log',
+                '$windir\\Debug\\UserMode\\ChkAcc.bak',
+                '$windir\\Debug\\UserMode\\userenv.bak',
+                '$windir\\Microsoft.NET\Framework\*\*.log',
+                '$windir\\pchealth\\helpctr\\Logs\\hcupdate.log',
+                '$windir\\security\\logs\\*.log',
+                '$windir\\security\\logs\\*.old',
+                '$windir\\system32\\TZLog.log',
+                '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.bak',
+                '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.txt',
+                '$windir\\system32\\LogFiles\\AIT\\AitEventLog.etl.???',
+                '$windir\\system32\\LogFiles\\Firewall\\pfirewall.log*',
+                '$windir\\system32\\LogFiles\\Scm\\SCM.EVM*',
+                '$windir\\system32\\LogFiles\\WMI\\Terminal*.etl',
+                '$windir\\system32\\LogFiles\\WMI\\RTBackup\EtwRT.*etl',
+                '$windir\\system32\\wbem\\Logs\\*.lo_',
                 '$windir\\system32\\wbem\\Logs\\*.log', )
 
             for path in paths:
                 expanded = os.path.expandvars(path)
                 for globbed in glob.iglob(expanded):
-                    files += [ globbed ]
+                    files += [globbed]
 
         # memory
         if sys.platform.startswith('linux') and 'memory' == option_id:
@@ -555,13 +603,13 @@ class System(Cleaner):
         if 'nt' == os.name and 'memory_dump' == option_id:
             fname = os.path.expandvars('$windir\\memory.dmp')
             if os.path.exists(fname):
-                files += [ fname ]
+                files += [fname]
             for fname in glob.iglob(os.path.expandvars('$windir\\Minidump\\*.dmp')):
-                files += [ fname ]
+                files += [fname]
 
         # most recently used documents list
         if 'posix' == os.name and 'recent_documents' == option_id:
-            files += [ os.path.expanduser("~/.recently-used") ]
+            files += [os.path.expanduser("~/.recently-used")]
             # GNOME 2.26 (as seen on Ubuntu 9.04) will retain the list
             # in memory if it is simply deleted, so it must be shredded
             # (or at least truncated).
@@ -578,15 +626,13 @@ class System(Cleaner):
                     if HAVE_GTK:
                         gtk.RecentManager().purge_items()
 
-
         if 'posix' == os.name and 'rotated_logs' == option_id:
             for path in Unix.rotated_logs():
                 yield Command.Delete(path)
 
-
         # temporary files
         if 'posix' == os.name and 'tmp' == option_id:
-            dirnames = [ '/tmp', '/var/tmp' ]
+            dirnames = ['/tmp', '/var/tmp']
             for dirname in dirnames:
                 for path in children_in_directory(dirname, True):
                     is_open = FileUtilities.openfiles.is_open(path)
@@ -599,14 +645,14 @@ class System(Cleaner):
 
         # temporary files
         if 'nt' == os.name and 'tmp' == option_id:
-            dirname = os.path.expandvars("$USERPROFILE\\Local Settings\\Temp\\")
+            dirname = os.path.expandvars(
+                "$USERPROFILE\\Local Settings\\Temp\\")
             for filename in children_in_directory(dirname, True):
                 yield Command.Delete(filename)
             dirname = os.path.expandvars("$windir\\temp\\")
             for filename in children_in_directory(dirname, True):
                 yield Command.Delete(filename)
 
-
         # trash
         if 'posix' == os.name and 'trash' == option_id:
             dirname = os.path.expanduser("~/.Trash")
@@ -640,7 +686,6 @@ class System(Cleaner):
                 return 0
             yield Command.Function(None, clear_clipboard, _('Clipboard'))
 
-
         # overwrite free space
         shred_drives = options.get_list('shred_drives')
         if 'free_disk_space' == option_id and shred_drives:
@@ -648,34 +693,34 @@ class System(Cleaner):
                 # TRANSLATORS: 'Free' means 'unallocated.'
                 # %s expands to a path such as C:\ or /tmp/
                 display = _("Overwrite free disk space %s") % pathname
+
                 def wipe_path_func():
-                    for ret in FileUtilities.wipe_path(pathname, idle = True):
+                    for ret in FileUtilities.wipe_path(pathname, idle=True):
                         # Yield control to GTK idle because this process
                         # is very slow.  Also display progress.
                         yield ret
                     yield 0
                 yield Command.Function(None, wipe_path_func, display)
 
-
         # MUICache
         if 'nt' == os.name and 'muicache' == option_id:
-            keys = ( 'HKCU\\Software\\Microsoft\\Windows\\ShellNoRoam\\MUICache',
-                'HKCU\\Software\\Classes\\Local Settings\\Software\\Microsoft\\Windows\\Shell\\MuiCache' )
+            keys = (
+                'HKCU\\Software\\Microsoft\\Windows\\ShellNoRoam\\MUICache',
+                'HKCU\\Software\\Classes\\Local Settings\\Software\\Microsoft\\Windows\\Shell\\MuiCache')
             for key in keys:
                 yield Command.Winreg(key, None)
 
-
         # prefetch
         if 'nt' == os.name and 'prefetch' == option_id:
             for path in glob.iglob(os.path.expandvars('$windir\\Prefetch\\*.pf')):
                 yield Command.Delete(path)
 
-
         # recycle bin
         if 'nt' == os.name and 'recycle_bin' == option_id:
             for drive in Windows.get_fixed_drives():
                 # TRANSLATORS: %s expands to a drive letter such as C:\ or D:\
                 label = _("Recycle bin %s") % drive
+
                 def emptyrecyclebin():
                     return Windows.empty_recycle_bin(drive, True)
                 # fixme: enable size preview
@@ -691,7 +736,6 @@ class System(Cleaner):
             if os.path.lexists(filename):
                 yield Command.Delete(filename)
 
-
     def whitelisted(self, pathname):
         """Return boolean whether file is whitelisted"""
         regexes = [
@@ -704,9 +748,10 @@ class System(Cleaner):
             '^/tmp/orbit-[^/]+/bonobo-activation-register[a-z0-9-]*.lock$',
             '^/tmp/orbit-[^/]+/bonobo-activation-server-[a-z0-9-]*ior$',
             '^/tmp/pulse-[^/]+/pid$',
-            '^/var/tmp/kdecache-' ]
-        regexes.append('^'+os.path.expanduser('~/.cache/wallpaper/'))
-        regexes.append('^'+os.path.expanduser('~/.cache/gnome-control-center/'))
+            '^/var/tmp/kdecache-']
+        regexes.append('^' + os.path.expanduser('~/.cache/wallpaper/'))
+        regexes.append(
+            '^' + os.path.expanduser('~/.cache/gnome-control-center/'))
         for regex in regexes:
             if None != re.match(regex, pathname):
                 return True
@@ -737,18 +782,21 @@ def register_cleaners():
 
 
 def create_simple_cleaner(paths):
+    """Shred arbitrary files (used in CLI and GUI)"""
     cleaner = Cleaner()
-    cleaner.add_option(option_id = 'files', name = '', description = '')
-    cleaner.name = _("System") # shows up in progress bar
+    cleaner.add_option(option_id='files', name='', description='')
+    cleaner.name = _("System")  # shows up in progress bar
 
     import Action
 
     class CustomFileAction(Action.ActionProvider):
         action_key = '__customfileaction'
+
         def get_commands(self):
             for path in paths:
                 if not isinstance(path, (str, unicode)):
-                    raise RuntimeError('expected path as string but got %s' % str(path))
+                    raise RuntimeError(
+                        'expected path as string but got %s' % str(path))
                 if os.path.isdir(path):
                     for child in children_in_directory(path, True):
                         yield Command.Shred(child)
@@ -761,23 +809,27 @@ def create_simple_cleaner(paths):
 
 
 def create_wipe_cleaner(path):
+    """Wipe free disk space of arbitrary paths (used in GUI)"""
     cleaner = Cleaner()
-    cleaner.add_option(option_id = 'free_disk_space', name = '', description = '')
+    cleaner.add_option(
+        option_id='free_disk_space', name='', description='')
     cleaner.name = ''
 
     # create a temporary cleaner object
     display = _("Overwrite free disk space %s") % path
+
     def wipe_path_func():
-        for ret in FileUtilities.wipe_path(path, idle = True):
+        for ret in FileUtilities.wipe_path(path, idle=True):
             yield ret
         yield 0
 
     import Action
+
     class CustomWipeAction(Action.ActionProvider):
         action_key = '__customwipeaction'
+
         def get_commands(self):
             yield Command.Function(None, wipe_path_func, display)
     provider = CustomWipeAction(None)
     cleaner.add_action('free_disk_space', provider)
     return cleaner
-
