@@ -1,22 +1,22 @@
 # vim: ts=4:sw=4:expandtab
 # -*- coding: UTF-8 -*-
 
-## BleachBit
-## Copyright (C) 2013 Andrew Ziem
-## http://bleachbit.sourceforge.net
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# BleachBit
+# Copyright (C) 2014 Andrew Ziem
+# http://bleachbit.sourceforge.net
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Code that is commonly shared throughout BleachBit
@@ -31,7 +31,7 @@ import sys
 if 'nt' == os.name:
     from win32com.shell import shell, shellcon
 
-APP_VERSION = "1.0"
+APP_VERSION = "1.2"
 APP_NAME = "BleachBit"
 APP_URL = "http://bleachbit.sourceforge.net"
 
@@ -43,28 +43,33 @@ socket_timeout = 10
 # for packages in repositories).
 online_update_notification_enabled = True
 
-###
-### Paths
-###
+#
+# Paths
+#
 
 # Windows
 bleachbit_exe_path = None
 if hasattr(sys, 'frozen'):
     # running frozen in py2exe
-    bleachbit_exe_path = os.path.dirname(unicode(sys.executable, sys.getfilesystemencoding()))
+    bleachbit_exe_path = os.path.dirname(
+        unicode(sys.executable, sys.getfilesystemencoding()))
 else:
     # __file__ is absolute path to bleachbit/Common.py
-    bleachbit_exe_path = os.path.dirname(unicode(__file__, sys.getfilesystemencoding()))
+    bleachbit_exe_path = os.path.dirname(
+        unicode(__file__, sys.getfilesystemencoding()))
 
 # license
 license_filename = None
-license_filenames = ('/usr/share/common-licenses/GPL-3', # Debian, Ubuntu
-    os.path.join(bleachbit_exe_path, 'COPYING'), # Microsoft Windows
-    '/usr/share/doc/bleachbit-' + APP_VERSION + '/COPYING', # CentOS, Fedora, RHEL
-    '/usr/share/doc/packages/bleachbit/COPYING', # OpenSUSE 11.1
-    '/usr/share/doc/bleachbit/COPYING', # Mandriva
-    '/usr/pkg/share/doc/bleachbit/COPYING', # NetBSD 5
-    '/usr/share/licenses/common/GPL3/license.txt' ) # Arch Linux
+license_filenames = ('/usr/share/common-licenses/GPL-3',  # Debian, Ubuntu
+                     os.path.join(
+                         bleachbit_exe_path, 'COPYING'),  # Microsoft Windows
+                     '/usr/share/doc/bleachbit-' + APP_VERSION +
+                     '/COPYING',  # CentOS, Fedora, RHEL
+                     '/usr/share/doc/packages/bleachbit/COPYING',
+                     # OpenSUSE 11.1
+                     '/usr/share/doc/bleachbit/COPYING',  # Mandriva
+                     '/usr/pkg/share/doc/bleachbit/COPYING',  # NetBSD 5
+                     '/usr/share/licenses/common/GPL3/license.txt')  # Arch Linux
 for lf in license_filenames:
     if os.path.exists(lf):
         license_filename = lf
@@ -89,22 +94,25 @@ options_file = os.path.join(options_dir, "bleachbit.ini")
 personal_cleaners_dir = os.path.join(options_dir, "cleaners")
 
 # system cleaners
-system_cleaners_dir = None
 if sys.platform.startswith('linux'):
     system_cleaners_dir = '/usr/share/bleachbit/cleaners'
 elif sys.platform == 'win32':
     system_cleaners_dir = os.path.join(bleachbit_exe_path, 'share\\cleaners\\')
 elif sys.platform[:6] == 'netbsd':
     system_cleaners_dir = '/usr/pkg/share/bleachbit/cleaners'
+else:
+    system_cleaners_dir = None
+    print 'warning: unknown system cleaners directory for platform ', sys.platform
 
 # local cleaners directory (for running from source tree)
-local_cleaners_dir =  os.path.normpath(os.path.join(bleachbit_exe_path, '../cleaners'))
+local_cleaners_dir = os.path.normpath(
+    os.path.join(bleachbit_exe_path, '../cleaners'))
 
 # application icon
-__icons = ( '/usr/share/pixmaps/bleachbit.png', # Linux
-    os.path.join(bleachbit_exe_path, 'share\\bleachbit.png'), # Windows
-    '/usr/pkg/share/pixmaps/bleachbit.png', # NetBSD
-    os.path.normpath(os.path.join(bleachbit_exe_path, '../bleachbit.png'))) # local
+__icons = ('/usr/share/pixmaps/bleachbit.png',  # Linux
+           os.path.join(bleachbit_exe_path, 'share\\bleachbit.png'),  # Windows
+           '/usr/pkg/share/pixmaps/bleachbit.png',  # NetBSD
+           os.path.normpath(os.path.join(bleachbit_exe_path, '../bleachbit.png')))  # local
 appicon_path = None
 for __icon in __icons:
     if os.path.exists(__icon):
@@ -128,12 +136,13 @@ else:
 # launcher
 launcher_path = '/usr/share/applications/bleachbit.desktop'
 if 'posix' == os.name:
-    autostart_path = os.path.expanduser('~/.config/autostart/bleachbit.desktop')
+    autostart_path = os.path.expanduser(
+        '~/.config/autostart/bleachbit.desktop')
 
 
-###
-### setup environment
-###
+#
+# setup environment
+#
 
 # Windows XP doesn't define localappdata, but Windows Vista and 7 do
 def environ(varname, csidl):
@@ -141,7 +150,8 @@ def environ(varname, csidl):
         os.environ[varname] = shell.SHGetSpecialFolderPath(None, csidl)
     except:
         traceback.print_exc()
-        msg = 'Error setting environemnt variable "%s": %s ' % (varname, str(sys.exc_info()[1]))
+        msg = 'Error setting environemnt variable "%s": %s ' % (
+            varname, str(sys.exc_info()[1]))
         import GuiBasic
         GuiBasic.message_dialog(None, msg)
 if 'nt' == os.name:
@@ -149,9 +159,9 @@ if 'nt' == os.name:
     environ('documents', shellcon.CSIDL_DESKTOPDIRECTORY)
 
 
-###
-### gettext
-###
+#
+# gettext
+#
 
 try:
     user_locale = locale.getdefaultlocale()[0]
@@ -186,9 +196,9 @@ except:
         return plural
 
 
-###
-### pgettext
-###
+#
+# pgettext
+#
 
 # Code released in the Public Domain. You can do whatever you want with this package.
 # Originally written by Pierre Métras <pierre@alterna.tv> for the OLPC XO laptop.
@@ -207,6 +217,7 @@ except:
 # module will include pgettext() function.
 GETTEXT_CONTEXT_GLUE = "\004"
 
+
 def pgettext(msgctxt, msgid):
     """A custom implementation of GNU pgettext().
     """
@@ -223,15 +234,14 @@ def pgettext(msgctxt, msgid):
 _p = lambda msgctxt, msgid: pgettext(msgctxt, msgid)
 
 
-###
-### URLs
-###
+#
+# URLs
+#
 
 
 base_url = "http://bleachbit.sourceforge.net"
 help_contents_url = "%s/link.php?version=%s&lang=%s&target=help" \
-    % ( base_url, APP_VERSION, user_locale )
+    % (base_url, APP_VERSION, user_locale)
 release_notes_url = "%s/link.php?version=%s&lang=%s&target=release_notes" \
-    % ( base_url, APP_VERSION, user_locale )
+    % (base_url, APP_VERSION, user_locale)
 update_check_url = "%s/communicate.php" % base_url
-
