@@ -1,23 +1,22 @@
 # vim: ts=4:sw=4:expandtab
 # -*- coding: UTF-8 -*-
 
-## BleachBit
-## Copyright (C) 2013 Andrew Ziem
-## http://bleachbit.sourceforge.net
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+# BleachBit
+# Copyright (C) 2014 Andrew Ziem
+# http://bleachbit.sourceforge.net
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 """
@@ -25,6 +24,7 @@ File-related utilities
 """
 
 
+import atexit
 import codecs
 import errno
 import glob
@@ -46,15 +46,16 @@ if 'posix' == os.name:
     from General import WindowsError
 
 
-
 class OpenFiles:
+
     """Cached way to determine whether a file is open by active process"""
+
     def __init__(self):
         self.last_scan_time = None
         self.files = []
 
     def file_qualifies(self, filename):
-        """Return boolean wehether filename qualifies to enter cache (check \
+        """Return boolean whether filename qualifies to enter cache (check \
         against blacklist)"""
         return not filename.startswith("/dev") and \
             not filename.startswith("/proc")
@@ -76,36 +77,36 @@ class OpenFiles:
     def is_open(self, filename):
         """Return boolean whether filename is open by running process"""
         if None == self.last_scan_time or (time.time() -
-            self.last_scan_time) > 10:
+                                           self.last_scan_time) > 10:
             self.scan()
         return filename in self.files
 
 
 def __random_string(length):
     """Return random alphanumeric characters of given length"""
-    return ''.join(random.choice(string.ascii_letters + '0123456789 _.-') \
-        for i in xrange(length))
+    return ''.join(random.choice(string.ascii_letters + '0123456789_.-')
+                   for i in xrange(length))
 
 
 def bytes_to_human(bytes_i):
     """Display a file size in human terms (megabytes, etc.) using SI standard"""
 
-    storage_multipliers = { 1000**5 : 'PB', 1000**4 : 'TB', \
-        1000**3 : 'GB', 1000**2: 'MB', 1000: 'kB', 1 : 'B' }
+    storage_multipliers = {1000 ** 5: 'PB', 1000 ** 4: 'TB',
+                           1000 ** 3: 'GB', 1000 ** 2: 'MB', 1000: 'kB', 1: 'B'}
 
     assert(isinstance(bytes_i, (int, long)))
 
     if 0 == bytes_i:
         return "0"
 
-    if bytes_i >= 1000**3:
+    if bytes_i >= 1000 ** 3:
         decimals = 2
     elif bytes_i >= 1000:
         decimals = 1
     else:
         decimals = 0
 
-    for key in sorted(storage_multipliers.keys(), reverse = True):
+    for key in sorted(storage_multipliers.keys(), reverse=True):
         if bytes_i >= key:
             abbrev = round((1.0 * bytes_i) / key, decimals)
             suf = storage_multipliers[key]
@@ -115,7 +116,7 @@ def bytes_to_human(bytes_i):
         return "-" + bytes_to_human(abs(bytes_i))
 
 
-def children_in_directory(top, list_directories = False):
+def children_in_directory(top, list_directories=False):
     """Iterate files and, optionally, subdirectories in directory"""
     if type(top) is tuple:
         for top_ in top:
@@ -130,7 +131,6 @@ def children_in_directory(top, list_directories = False):
             yield os.path.join(dirpath, filename)
 
 
-
 def clean_ini(path, section, parameter):
     """Delete sections and parameters (aka option) in the file"""
 
@@ -199,10 +199,18 @@ def clean_json(path, target):
         json.dump(js, open(path, 'w'))
 
 
-def delete(path, shred = False):
-    """Delete path that is either file, directory, link or FIFO"""
+def delete(path, shred=False, ignore_missing=False, allow_shred=True):
+    """Delete path that is either file, directory, link or FIFO.
+
+       If shred is enabled as a function parameter or the BleachBit global
+       parameter, the path will be shredded unless allow_shred = False.
+    """
     from Options import options
     is_special = False
+    if not os.path.lexists(path):
+        if ignore_missing:
+            return
+        raise OSError(2, 'No such file or directory', path)
     if 'posix' == os.name:
         # With certain (relatively rare) files on Windows os.lstat()
         # may return Access Denied
@@ -212,7 +220,7 @@ def delete(path, shred = False):
         os.remove(path)
     elif os.path.isdir(path):
         delpath = path
-        if shred or options.get('shred'):
+        if allow_shred and (shred or options.get('shred')):
             delpath = wipe_name(path)
         try:
             os.rmdir(delpath)
@@ -234,17 +242,16 @@ def delete(path, shred = False):
                 raise
     elif os.path.isfile(path):
         # wipe contents
-        if shred or options.get('shred'):
+        if allow_shred and (shred or options.get('shred')):
             try:
                 wipe_contents(path)
             except IOError, e:
                 # permission denied (13) happens shredding MSIE 8 on Windows 7
                 print "debug: IOError #%s shredding '%s'" % (e.errno, path)
-        # wipe name
-        if shred or options.get('shred'):
+            # wipe name
             os.remove(wipe_name(path))
-        # unlink
         else:
+            # unlink
             os.remove(path)
     else:
         print "info: special file type cannot be deleted: '%s'" % (path)
@@ -289,7 +296,8 @@ def execute_sqlite3(path, cmds):
             raise sqlite3.DatabaseError('%s: %s' % (exc, path))
         except sqlite3.OperationalError, exc:
             if exc.message.find('no such function: ') >= 0:
-                # fixme: determine why randomblob and zeroblob are not available
+                # fixme: determine why randomblob and zeroblob are not
+                # available
                 print 'warning: %s' % exc.message
             else:
                 raise sqlite3.OperationalError('%s: %s' % (exc, path))
@@ -301,7 +309,8 @@ def execute_sqlite3(path, cmds):
 def expand_glob_join(pathname1, pathname2):
     """Join pathname1 and pathname1, expand pathname, glob, and return as list"""
     ret = []
-    pathname3 = os.path.expanduser(os.path.expandvars(os.path.join(pathname1, pathname2)))
+    pathname3 = os.path.expanduser(
+        os.path.expandvars(os.path.join(pathname1, pathname2)))
     for pathname4 in glob.iglob(pathname3):
         ret.append(pathname4)
     return ret
@@ -312,8 +321,8 @@ def free_space(pathname):
     if 'nt' == os.name:
         import ctypes
         free_bytes = ctypes.c_int64()
-        ctypes.windll.kernel32.GetDiskFreeSpaceExW(unicode(pathname), \
-            ctypes.byref(free_bytes), None, None)
+        ctypes.windll.kernel32.GetDiskFreeSpaceExW(unicode(pathname),
+                                                   ctypes.byref(free_bytes), None, None)
         return free_bytes.value
     mystat = os.statvfs(pathname)
     return mystat.f_bfree * mystat.f_bsize
@@ -334,13 +343,14 @@ def getsize(path):
             raise
         return __stat.st_blocks * 512
     if 'nt' == os.name:
-        # On rare files os.path.getsize() returns access denied, so try FindFilesW instead
+        # On rare files os.path.getsize() returns access denied, so try
+        # FindFilesW instead
         finddata = win32file.FindFilesW(path)
         if finddata == []:
             # FindFilesW doesn't work for directories, so fallback to getsize()
             return os.path.getsize(path)
         else:
-            size = (finddata[0][4] * (0xffffffff+1)) + finddata[0][5]
+            size = (finddata[0][4] * (0xffffffff + 1)) + finddata[0][5]
             return size
     return os.path.getsize(path)
 
@@ -348,7 +358,7 @@ def getsize(path):
 def getsizedir(path):
     """Return the size of the contents of a directory"""
     total_bytes = 0
-    for node in children_in_directory(path, list_directories = False):
+    for node in children_in_directory(path, list_directories=False):
         total_bytes += getsize(node)
     return total_bytes
 
@@ -365,23 +375,50 @@ def globex(pathname, regex):
                 yield path
 
 
-def human_to_bytes(human, hformat = 'si'):
+def guess_overwrite_paths():
+    """Guess which partitions to overwrite (to hide deleted files)"""
+    # In case overwritting leaves large files, placing them in
+    # ~/.config makes it easy to find them and clean them.
+    ret = []
+    if 'posix' == os.name:
+        home = os.path.expanduser('~/.cache')
+        if not os.path.exists(home):
+            home = os.path.expanduser("~")
+        ret.append(home)
+        if not same_partition(home, '/tmp/'):
+            ret.append('/tmp')
+    elif 'nt' == os.name:
+        localtmp = dirname = os.path.expandvars(
+            "$USERPROFILE\\Local Settings\\Temp\\")
+        from Windows import get_fixed_drives
+        for drive in get_fixed_drives():
+            if same_partition(localtmp, drive):
+                ret.append(localtmp)
+            else:
+                ret.append(drive)
+    else:
+        NotImplementedError('Unsupported OS in guess_overwrite_paths')
+    return ret
+
+
+def human_to_bytes(human, hformat='si'):
     """Convert a string like 10.2GB into bytes.  By
     default use SI standard (base 10).  The format of the
     GNU command 'du' (base 2) also supported."""
     if 'si' == hformat:
-        multiplier = { 'B' : 1, 'kB': 1000, 'MB': 1000**2, \
-            'GB': 1000**3, 'TB': 1000**4 }
+        multiplier = {'B': 1, 'kB': 1000, 'MB': 1000 ** 2,
+                      'GB': 1000 ** 3, 'TB': 1000 ** 4}
         matches = re.findall("^([0-9]*)(\.[0-9]{1,2})?([kMGT]{0,1}B)$", human)
     elif 'du' == hformat:
-        multiplier = { 'B' : 1, 'KB': 1024, 'MB': 1024**2, \
-            'GB': 1024**3, 'TB': 1024**4 }
+        multiplier = {'B': 1, 'KB': 1024, 'MB': 1024 ** 2,
+                      'GB': 1024 ** 3, 'TB': 1024 ** 4}
         matches = re.findall("^([0-9]*)(\.[0-9]{1,2})?([KMGT]{0,1}B)$", human)
     else:
         raise ValueError("Invalid format: '%s'" % hformat)
     if [] == matches or 2 > len(matches[0]):
-        raise ValueError("Invalid input for '%s' (hformat='%s')" % (human, hformat))
-    return int(float(matches[0][0]+matches[0][1]) * multiplier[matches[0][2]])
+        raise ValueError(
+            "Invalid input for '%s' (hformat='%s')" % (human, hformat))
+    return int(float(matches[0][0] + matches[0][1]) * multiplier[matches[0][2]])
 
 
 def listdir(directory):
@@ -401,6 +438,16 @@ def listdir(directory):
         yield os.path.join(dirname, filename)
 
 
+def same_partition(dir1, dir2):
+    """Are both directories on the same partition?"""
+    if 'nt' == os.name:
+        return free_space(dir1) == free_space(dir2)
+    stat1 = os.statvfs(dir1)
+    stat2 = os.statvfs(dir2)
+    return (stat1.f_blocks == stat2.f_blocks and
+            stat1.f_bfree == stat2.f_bfree)
+
+
 def sync():
     """Flush file system buffers. sync() is different than fsync()"""
     if 'posix' == os.name:
@@ -439,7 +486,7 @@ def whitelisted(path):
     return False
 
 
-def wipe_contents(path, truncate = True):
+def wipe_contents(path, truncate=True):
     """Wipe files contents
 
     http://en.wikipedia.org/wiki/Data_remanence
@@ -451,17 +498,17 @@ def wipe_contents(path, truncate = True):
     try:
         f = open(path, 'wb')
     except IOError, e:
-        if e.errno == errno.EACCES: # permission denied
-            os.chmod(path, 0200) # user write only
+        if e.errno == errno.EACCES:  # permission denied
+            os.chmod(path, 0200)  # user write only
             f = open(path, 'wb')
         else:
             raise
-    blanks =  chr(0) * 4096
+    blanks = chr(0) * 4096
     while size > 0:
         f.write(blanks)
         size -= 4096
-    f.flush() # flush to OS buffer
-    os.fsync(f.fileno()) # force write to disk
+    f.flush()  # flush to OS buffer
+    os.fsync(f.fileno())  # force write to disk
     if truncate:
         f.truncate(0)
         f.flush()
@@ -469,16 +516,25 @@ def wipe_contents(path, truncate = True):
     f.close()
 
 
-def wipe_inodes(pathname):
+def wipe_inodes(pathname, idle=False):
     """Create empty files with long names to clear remanence in metadata"""
     # When the file system is full, Linux 3.5 will sometimes
     # give an error and sometimes succeed.
     errors = 0
     files = []
-    suffix = ' ' * (os.statvfs(pathname).f_namemax - len(pathname) - 10)
+    if 'nt' == os.name:
+        # 255 according to http://en.wikipedia.org/wiki/Long_filename
+        f_namemax = 250
+        if not pathname.endswith('\\'):
+            pathname += '\\'
+    elif 'posix' == os.name:
+        f_namemax = os.statvfs(pathname).f_namemax
+        stats = os.statvfs(pathname)
+        inodes_avail_original = stats.f_favail
+    suffix = ' ' * (f_namemax - len(pathname) - 10)
     print 'info: creating empty files'
     print 'debug: suffix length = ', len(suffix)
-
+    last_idle = time.time()
     # Creating the files in a sub-directory improves recovery
     # of disk space:
     # http://bleachbit.sourceforge.net/news/deleting-files-doesnt-free-disk-space
@@ -488,27 +544,71 @@ def wipe_inodes(pathname):
     # create empty files until file system is exhausted
     while True:
         try:
-            (fd, fn) = tempfile.mkstemp(dir=tmpdir, suffix=suffix, prefix = '')
+            (fd, fn) = tempfile.mkstemp(dir=tmpdir, suffix=suffix, prefix='')
+        except KeyboardInterrupt:
+            print 'info: wipe_inodes: keyboard interrupt'
+            break
         except:
-            #print 'error', sys.exc_info()[1]
+            print 'error', sys.exc_info()[1]
             errors += 1
+            if os.path.exists(fn):
+                # on Windows with FAT32, files sometimes exist despite error
+                files.append(fn)
+            try:
+                os.close(fd)
+            except:
+                pass
         else:
             errors = 0
             files.append(fn)
             os.close(fd)
-        if errors > 10 or 0 == os.statvfs(pathname).f_ffree:
+            if idle and (time.time() - last_idle) > 2:
+                stats = os.statvfs(pathname)
+                percent_done = None  # not implemented on Windows
+                if 'posix' == os.name:
+                    if inodes_avail_original > 0:
+                        percent_done = 1.0 * \
+                            (inodes_avail_original - stats.f_favail) / \
+                            inodes_avail_original
+                    else:
+                        percent_done = 1.0
+                yield (2, percent_done, None)
+                last_idle = time.time()
+            # In case the application closes prematurely, make sure this file
+            # is deleted
+            atexit.register(delete, fn, allow_shred=False, ignore_missing=True)
+        if errors > 10:
+            break
+        if 'posix' == os.name and 0 == os.statvfs(pathname).f_ffree:
             break
 
     # flush once because it is slow
     sync()
 
     # display effectiveness
-    stats = os.statvfs(pathname)
-    print 'info: %d inodes available, %d to super user' % (stats.f_ffree, stats.f_favail)
+    if 'posix' == os.name:
+        stats = os.statvfs(pathname)
+        print 'info: %d inodes available, %d to super user' % (stats.f_ffree, stats.f_favail)
 
     # clean up
+    files_len_original = len(files)
+    files_remaining = len(files)
+    print 'info: deleting %d empty files' % files_len_original
     for f in files:
-        os.remove(f)
+        try:
+            os.remove(f)
+        except:
+            if os.path.exists(f):
+                print 'warning: could not delete empty file %s' % f
+            else:
+                print 'warning: exception deleting empty file %s' % f
+        files_remaining = - 1
+        if idle and (time.time() - last_idle) > 2:
+            percent_done = 1.0 * \
+                (files_len_original - len(files)) / files_len_original
+            yield (3, percent_done, None)
+            last_idle = time.time()
+
     os.rmdir(tmpdir)
     print 'debug: done deleting empty files'
 
@@ -549,19 +649,25 @@ def wipe_name(pathname1):
     return pathname3
 
 
-def wipe_path(pathname, idle = False ):
+def wipe_path(pathname, idle=False):
     """Wipe the free space in the path"""
     def temporaryfile():
-        # reference http://en.wikipedia.org/wiki/Comparison_of_file_systems#Limits
+        # reference
+        # http://en.wikipedia.org/wiki/Comparison_of_file_systems#Limits
         maxlen = 245
         f = None
         i = 0
         while True:
             try:
-                kwargs = { 'dir' : pathname, 'suffix' : __random_string(maxlen) }
+                kwargs = {
+                    'dir': pathname, 'suffix': __random_string(maxlen)}
                 if sys.hexversion >= 0x02060000:
                     kwargs['delete'] = False
                 f = tempfile.NamedTemporaryFile(**kwargs)
+                # In case the application closes prematurely, make sure this
+                # file is deleted
+                atexit.register(
+                    delete, f.name, allow_shred=False, ignore_missing=True)
                 break
             except OSError, e:
                 if e.errno in (errno.ENAMETOOLONG, errno.ENOSPC):
@@ -573,7 +679,6 @@ def wipe_path(pathname, idle = False ):
                 raise
         return f
 
-
     def estimate_completion():
         """Return (percent, seconds) to complete"""
         remaining_bytes = free_space(pathname)
@@ -586,10 +691,9 @@ def wipe_path(pathname, idle = False ):
         else:
             done_percent = 1.0 * done_bytes / (start_free_bytes + 1)
         done_time = time.time() - start_time
-        rate = done_bytes / (done_time + 0.0001) # bytes per second
-        remaining_seconds = int(remaining_bytes / (rate+0.0001))
-        return (done_percent, remaining_seconds)
-
+        rate = done_bytes / (done_time + 0.0001)  # bytes per second
+        remaining_seconds = int(remaining_bytes / (rate + 0.0001))
+        return (1, done_percent, remaining_seconds)
 
     print "debug: wipe_path('%s')" % pathname
     files = []
@@ -619,7 +723,7 @@ def wipe_path(pathname, idle = False ):
                 if e.errno == errno.ENOSPC:
                     if len(blanks) > 1:
                         # Try writing smaller blocks
-                        blanks = blanks[0 : (len(blanks)/2)]
+                        blanks = blanks[0: (len(blanks) / 2)]
                     else:
                         break
                 elif e.errno != errno.EFBIG:
@@ -637,7 +741,7 @@ def wipe_path(pathname, idle = False ):
             # seen on Microsoft Windows XP SP3 with ~30GB free space but
             # not on another XP SP3 with 64MB free space
             print "info: exception on f.flush()"
-        os.fsync(f.fileno()) # write to disk
+        os.fsync(f.fileno())  # write to disk
         # Remember to delete
         files.append(f)
         # For statistics
@@ -649,7 +753,7 @@ def wipe_path(pathname, idle = False ):
     sync()
     # statistics
     elapsed_sec = time.time() - start_time
-    rate_mbs = (total_bytes / (1000*1000) ) / elapsed_sec
+    rate_mbs = (total_bytes / (1000 * 1000)) / elapsed_sec
     print 'note: wrote %d files and %d bytes in %d seconds at %.2f MB/s' % \
         (len(files), total_bytes, elapsed_sec, rate_mbs)
     # how much free space is left (should be near zero)
@@ -674,9 +778,6 @@ def wipe_path(pathname, idle = False ):
                     time.sleep(0.1)
         # explicitly delete
         delete(f.name)
-    # quickly wipe inodes
-    if 'posix' == os.name and os.statvfs(pathname).f_ffree > 0:
-        wipe_inodes(pathname)
 
 
 def vacuum_sqlite3(path):
@@ -685,6 +786,3 @@ def vacuum_sqlite3(path):
 
 
 openfiles = OpenFiles()
-
-
-
